| Title: | Journal Citation Reports ('JCR') Impact Factor by 'Clarivate' 'Analytics' |
|---|---|
| Description: | The Impact Factor of a journal reported by Journal Citation Reports ('JCR') of 'Clarivate' 'Analytics' is provided. The impact factor is available for those journals only that were included Journal Citation Reports 'JCR'. |
| Authors: | Shahla Faisal |
| Maintainer: | Shahla Faisal <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-06-05 10:23:19 UTC |
| Source: | https://github.com/cran/JCRImpactFactor |
This function gives the Impact Factor of the journal(s) provided by Journal Citation Reports (JCR) Thomson Reuters for the year 1997 to 2019. If the output shows a NA for a journal, it means that the journal has never been in JCR list.
find.IF.JCR(journals, year, exact.match = TRUE)find.IF.JCR(journals, year, exact.match = TRUE)
journals |
a |
year |
|
exact.match |
|
impact factor of the journal(s)
find.IF.JCR("ieee access") find.IF.JCR( "ieee access", year=2016)find.IF.JCR("ieee access") find.IF.JCR( "ieee access", year=2016)
This package provides the Impact Factor of a journal reported by Journal Citation Reports (JCR) of Clarivate Analytics. The impact factor is provided for only those journals that are included Journal Citation Reports (JCR).
| Package: JCRImpactFactor | JCR |
| Version: | 1.0.0 |
| Date: | 2021-04-20 |
| Depends: | R (>= 3.5.0) |
| License: | GPL (>= 3) |
Shahla Faisal [email protected]
InCites journal citation reports, clarivate analytics.