Welcome to ClientVPS Mirrors

Help for package JCRImpactFactor
Title: Journal Citation Reports ('JCR') Impact Factor by 'Clarivate' 'Analytics'
Version: 1.0.0
Author: Shahla Faisal
Maintainer: Shahla Faisal <shahla_ramzan@yahoo.com>
Description: The Impact Factor of a journal reported by Journal Citation Reports ('JCR') of 'Clarivate' 'Analytics' is provided. The impact factor is available for those journals only that were included Journal Citation Reports 'JCR'.
License: GPL-3
Encoding: UTF-8
Imports: stringr
RoxygenNote: 7.1.1
Depends: R (≥ 3.5.0)
NeedsCompilation: no
Packaged: 2021-05-02 11:36:20 UTC; ShahlaFaisal
Repository: CRAN
Date/Publication: 2021-05-03 07:50:09 UTC

Journal Citation Reports (JCR) Impact Factor by Clarivate Analytics

Description

This package provides the Impact Factor of a journal reported by Journal Citation Reports (JCR) of Clarivate Analytics. The impact factor is provided for only those journals that are included Journal Citation Reports (JCR).

Details

Package: JCRImpactFactor JCR
Version: 1.0.0
Date: 2021-04-20
Depends: R (>= 3.5.0)
License: GPL (>= 3)

Author(s)

Shahla Faisal shahla_ramzan@yahoo.com

References

InCites journal citation reports, clarivate analytics.


find.IF.JCR Journal Citation Reports (JCR) Impact Factor

Description

This function gives the Impact Factor of the journal(s) provided by Journal Citation Reports (JCR) Thomson Reuters for the year 1997 to 2019. If the output shows a NA for a journal, it means that the journal has never been in JCR list.

Usage

find.IF.JCR(journals, year, exact.match = TRUE)

Arguments

journals

a character vector containing journals whose impact factor is required

year

scaler, the year for which impact factor is required. If not mensioned, then impact factor for all year is displayed.

exact.match

logical.

Value

impact factor of the journal(s)

Examples

   find.IF.JCR("ieee access")
   find.IF.JCR( "ieee access", year=2016)


Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.